@@ -1,9 +1,9 @@
 from functools import wraps
 
-_monitoring = {}
+monitoring = {}
 
 
-def thread_monitor(f):
+def thread_monitor(func):
     """
     A decorator to bse used in monitoring functions that have any possibility of causing a deadlock
 
@@ -14,26 +14,26 @@ def thread_monitor(f):
     monitored function is running at any point in time
 
     Args:
-        :param f: a function which will be added to the monitoring dict
-        :type f: class:`function`
+        :param func: a function which will be added to the monitoring dict
+        :type func: class:`function`
     """
 
-    _name = f"{f.__module__.split('.')[-1]}.{f.__name__}()"
-    _monitoring.update({_name: 0})
+    name = f"{func.__module__.split('.')[-1]}.{func.__name__}()"
+    monitoring.update({name: 0})
 
-    @wraps(f)
+    @wraps(func)
     def wrapper(*args, **kwargs):
         error = None
 
-        _monitoring[_name] += 1
+        monitoring[name] += 1
 
         try:
-            result = f(*args, **kwargs)
+            result = func(*args, **kwargs)
         except Exception as e:
             error = e
             result = None
 
-        _monitoring[_name] -= 1
+        monitoring[name] -= 1
 
         if error:
             raise error
